#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['onaws']

package_data = \
{'': ['*']}

install_requires = \
['requests']

entry_points = \
{'console_scripts': ['onaws = onaws:__main__.main']}

setup(name='onaws',
      version='0.0.12',
      description='Simple library to check if a hostname belongs to AWS IP space.',
      author='Amal Murali',
      author_email='amalmurali47@gmail.com',
      url='https://github.com/amalmurali47/onaws',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
